library( ANTsR )
library( patchMatchR )
library( keras )
layout( matrix(1:2,nrow=1) )
set.seed( Sys.time() )
fn1 = "fish1b.nii.gz"
fn2 = "fish2.png"
idim = antsImageRead( fn1 )@dimension
rsm = rep( 2, idim )
toScalar <- function( x ) {
  mgg = antsImageRead( x )
  mggs = splitChannels( mgg )
  sqrt( mggs[[1]]^2 + mggs[[2]]^2 + mggs[[3]]^2  )
}
img <- toScalar( fn1 ) %>% iMath( "Normalize" ) %>% resampleImage( rsm ) %>%
  iMath("PadImage",50)
img2 <- toScalar( fn2 ) %>% iMath( "Normalize" ) %>% resampleImage( rsm )
msk2 = getMask( img2, 0.05,0.73 , cleanup=1 )
msk1 = getMask( img, 0.01,0.98 , cleanup=1 )
plot( img * msk1 )
plot( img2 * msk2 )
reg = antsRegistration( img*msk1, img2*msk2, "Rigid" )
img2 = antsApplyTransforms( img, img2, reg$fwdtransforms )
msk2 = antsApplyTransforms( img, msk2, reg$fwdtransforms )
plot( img )
plot( img2 )
nP1 = 1000
nP2 = 5000
psz = 64
#<#############>oooo<#############>oooo<#############>oooo<#############>oooo###
# mask = antsImageRead( 'fish1_lm.nii.gz' )
manualmask = antsImageRead( "fish1_manual_lm.nii.gz", dimension=2 ) %>%
  thresholdImage( 1, Inf )
mask = randomMask( msk1, nP1, seed=Sys.time() )# %>% iMath("GD",3)
mask2 = randomMask( msk2, nP2, seed=Sys.time()  )
matchO = deepPatchMatch( img2, img, mask2, mask, psz, psz, verbose = TRUE )
mlm = matchedLandmarks( matchO, img, img2, rep(psz,img@dimension) )
mxct = 32
k = sample(1:nrow( mlm$fixedPoints), mxct, replace=T )
lmImage1 = makePointsImage( matrix(mlm$fixedPoints[k,],ncol=idim), img, radius = 15 )
lmImage2 = makePointsImage( matrix(mlm$movingPoints[k,],ncol=idim), img2, radius = 15 )
layout( matrix(1:2,nrow=1) )
plot( img*222, lmImage1  )
plot( img2*222, lmImage2 )
antsImageWrite( img, 'fish1_processed.nii.gz' )
antsImageWrite( img2, 'fish2_processed.nii.gz' )
antsImageWrite( lmImage2, 'fish2_processed_lm.nii.gz' )
antsImageWrite( lmImage1, 'fish1_processed_lm.nii.gz' )
